declare const SzyxPush: ISzyxPush;
export default SzyxPush;


export declare type OS_TYPE = "ios" | "android" | "web" | "windows" | "mac" | "unknown";
export declare type MsgType = "text" | "unknown";
export declare type MessageListener = (messageType: MsgType, message: Message) => void;

/**
 * 当messageType为text的时候，返回这个
 */
export declare interface TextMessage {
    text: string
}

export declare interface PictureMessage {
    url: string
}

export declare interface Message {
    /**
     * 租户id
     */
    tenantNo: string;
    messageType: MsgType;
    messageId: string;
    target: string;
    fromClientId: string;
    toClientId: string;
    timestamp: number;
    message: string | TextMessage | PictureMessage;
}


export declare interface ISzyxPush {

    /**
     * 初始化方法，建议放在main.js中
     * @param tenantNo 租户id，在平台获取
     * @param osType 设备类型
     */
    init(tenantNo: string, osType: OS_TYPE): Promise<void>;

    register(userId: string): Promise<void>;

    /**
     *添加消息回调，到达的消息统一分发入口
     * @param callback
     * @return callbackId 页面关闭时记得用 {@link unMessage}注销
     */
    onMessage(callback: MessageListener): number;

    /**
     *注销消息回调
     * @param callId 由{@link onMessage}返回
     */
    unMessage(callId): void;

    sendTextMsg(userId: string, text: string): Promise<Message>;
}
